class Cell {
	constructor (config) {
		const {name, selfPath, schema, mycellium, port} = config

		if (!selfPath) {
			throw 'selfPath is required'
		}

		this.env = process.env.NODE_ENV || 'local'
		console.log('RUNNING ON ENV: ', this.env)
		this.name = name
		this.config = {
			port: port || 1123,
			...config,
			cellPath: __dirname,
			selfPath
		}

		this.mycellium = mycellium || {}
		this.subscribers = {}
		// this.sockets = {}

		this.schema = schema || (() => {
			try {
				const schemaPath = `${selfPath}/${this.name}Schema.js`
				console.log(schemaPath);
				const schema = require(schemaPath)

				return schema
			} catch (error) {
				console.error(`No local schema found for ${this.name}`)
			}
		})()

		this.setActions = require('../_methods/setActions').bind(this)
		this.setReactions = require('../_methods/setReactions').bind(this)
		this.setModel = require('../_methods/setModel').bind(this)
		this.setPublisher = require('../_methods/setPublisher').bind(this)
		this.subscribeToMycellium = require('../_methods/cell/subscribeToMycellium').bind(this)
		this.onSocketConnection = require('../_methods/sockets/onSocketConnection').bind(this)
		this.socketServer = require('../_methods/sockets/socketServer').bind(this)
		this.expressServer = require('../_methods/sockets/expressServer').bind(this)
		this.wake = require('../_methods/wake').bind(this)
	}

	async run () {
		// Set actions
		this.setActions()

		// Set reactions
		this.setReactions()

		// Set Model if 'db' and 'schema' configured
		if (
			this.config.mycologies
			&& this.config.mycologies[this.env]
			&& this.config.mycologies[this.env].db
			&& this.schema
		)
			this.setModel()

		// await this.expressServer()

		// Set Redis publisher
		await this.setPublisher()

		// Set Socket server
		if (this.name === 'Monitor')
			await this.socketServer()

		// Listen for Mycellium calls
		await this.subscribeToMycellium()

		// Publish wake event
		this.wake()
	}

	/*setIndex () {
		this.indexClient = new require('elasticsearch').Client({
			host: 'localhost:9200'
		})

		/!*this.indexClient.ping({
		  requestTimeout: 1000
		}, function (error) {
		  if (error) {
			console.trace('elasticsearch cluster is down!');
		  } else {
			console.log('All is well');
		  }
		});*!/
	}*/
}

module.exports = Cell