require('colors')

class Mycellium {
	constructor (config = {}) {
		this.env = process.env.NODE_ENV || 'local'
		console.log('RUNNING ON ENV: ', this.env)
		this.name = 'Mycellium'
		this.config = {
			...config,

			// Default configs
			cellPath: __dirname,
			port: config.port || 1123
		}

		this.subscribers = {}
		// this.sockets = {}
		// this.accountSockets = {}

		if (this.config.rateLimit)
			this.floods = {}

		// Methods
		this.setActions = require('../_methods/setActions').bind(this)
		this.setReactions = require('../_methods/setReactions').bind(this)
		this.setPublisher = require('../_methods/setPublisher').bind(this)
		this.subscribeToCells = require('../_methods/subscribeToCells').bind(this)
		this.onSocketConnection = require('../_methods/sockets/onSocketConnection').bind(this)
		this.socketServer = require('../_methods/sockets/socketServer').bind(this)
		this.wake = require('../_methods/wake').bind(this)
	}

	async run () {
		// Set actions
		await this.setActions()

		// Set reactions
		await this.setReactions()

		// Set Redis publisher
		await this.setPublisher()

		// Set listening socket server
		await this.socketServer()

		// Listen for Cells
		await this.subscribeToCells()

		// Publish wake event
		this.wake()

		const instance = process.env.NODE_APP_INSTANCE
		const name = `${this.name}${typeof instance !== undefined ? `_${instance}` : ''}`

		console.log(`${name} is ready`.green)
	}
}

module.exports = Mycellium