import React, { Component } from 'react'
import classnames from 'classnames'
import './MonitorOn.scss'
import moment from 'moment/moment'

export default class EventRow extends Component {
	render () {
		const {columns, request, response, reactions, collapsed, status, i, setExpanded} = this.props

		const start = request && new Date(request.time).getTime()
		const end = response && new Date(response.time).getTime()

		return [
			<tr
				key={`${request.str}_${request.id}-collapse`}
				className={classnames(i % 2 === 0 ? 'even' : 'odd', 'collapse')}
				onClick={() => {
					setExpanded(request.id)
				}}
			>
				<td>
					<span className={classnames('status', status.toLowerCase())}
					      title={status}>
						{status}
					</span>
				</td>
				<td>{request && request.str}</td>
				<td>{request && request.id}</td>
				<td>{request && request.ip && request.ip.replace('::ffff:', '')}</td>
				<td>{request && request.socketId}</td>
				<td>{moment(request && request.time).format('hh:mm:ss.SSS')}</td>
				<td>{start && end && `${Math.abs(start - end)}ms`}</td>
			</tr>,
			<tr key={`${request.str}_${request.id}-expand`}
			    className={classnames(i % 2 === 0 ? 'even' : 'odd', 'expand', {'collapsed': collapsed})}>
				<td colSpan={columns.length}>
					<div className="tr-open">
						<div className="block">
							<h4>Request</h4>
							<textarea disabled value={JSON.stringify(request, null, 4)}/>
						</div>
						<div className="block">
							<h4>Response</h4>
							<textarea disabled value={JSON.stringify(response, null, 4)}/>
						</div>
					</div>
					{reactions.map((reaction, i) => {
						return (
							<div className="tr-open" key={`${reaction.id}_${i}`}>
								<div className="block">
									<h4>{reaction.str}</h4>
									<textarea disabled value={JSON.stringify(reaction, null, 4)}/>
								</div>
							</div>
						)
					})}
				</td>
			</tr>
		]
	}
}