import React, { Component } from 'react'
import { observer } from 'mobx-react'
import Header from '../../components/Header/Header'
import Table from '../../components/Table/Table'
import request from '../../../../../utils/request'
import mapData from './mapData'
import './MonitorOn.scss'
import EventRow from './EventRow'
import Timeline from './Timeline/Timeline'
import store from '../../mobx/store'

const columns = [
	{
		key: 'reactions',
		title: '',
		width: '100px'
	},
	{
		key: 'request',
		title: 'Request',
		width: '260px'
	},
	{
		key: 'id',
		title: 'Id',
		// width: '380px'
	},
	{
		key: 'ip',
		title: 'Ip',
		width: '200px'
	},
	{
		key: 'socketId',
		title: 'SocketId'
	},
	{
		key: 'time',
		title: 'Time',
		width: '200px'
	},
	{
		key: 'duration',
		title: 'Duration',
		width: '150px'
	},
	/*{
		key: 'status',
		title: 'Status'
	}*/
]

@observer
export default class MonitorOn extends Component {
	state = {
		loading: true,
		tab: 'Fire',
		expanded: []
	}

	componentDidMount () {
		this.int = setInterval(async () => {
			const res = await request(monitorClient, {
				str: 'GET.Monitor.Model._get',
				token: this.props.store.admin.token,
				body: {
					limit: 100
				}
			})

			this.props.store.events = [...res.body]
		}, 3000)
	}

	selectTab (tab) {
		this.setState({
			tab
		})
	}

	setExpanded (id) {
		this.setState({
			expanded: this.state.expanded.indexOf(id) > -1 ? this.state.expanded.splice(this.state.expanded.indexOf(id) + 1, 1) : [...this.state.expanded, id]
		})
	}

	reset () {
		this.setState({
			expanded: []
		})

		this.props.store.events = []
	}

	render () {
		const {events} = this.props.store
		const {tab, expanded} = this.state

		// const data = mapData(events)

		return (
			<div className="monitor-on">
				<Header
					tab={tab}
					onTabClick={this.selectTab.bind(this)}
					reset={this.reset.bind(this)}
				/>

				{/*{events.map((event ,i) => {
					return (
						<div key={i} style={{fontSize: '0.7em'}}>{JSON.stringify(event, null, 4)}</div>
					)
				})}*/}

				{/*<button style={{
					position: 'fixed',
					top: '15px',
					right: '15px'
				}} onClick={async () => {
					const res = await request(mycelliumClient, {
						str: 'GET.Mycellium.Service.ping'
					})

					console.log(res)
				}}>TEST LOGIN REQUEST
				</button>*/}

				{/*<Timeline
					store={store}
				/>*/}

				<Table
					columns={columns}
					expanded={expanded}
					mapBody={() => {
						return [...events]/*.filter((item, i) => i < 50)*/.reverse().map((item, i) => {
							const {
								id,
								accountId,
								socketId,
								ip,
								method,
								service,
								section,
								action,
								event,
								time,
								body,
								instance
							} = item

							const response = item.response && JSON.parse(item.response)

							const collapsed = expanded.indexOf(id) === -1
							const status = response && response.str && response.str.indexOf('.ERROR') > -1 ? 'ERROR' : response && response.str && response.str.indexOf('.SUCCESS') > -1 ? 'SUCCESS' : 'UNKNOWN'

							return (
								<EventRow
									columns={columns}
									request={{
										id,
										ip,
										socketId,
										time,
										str: `${method}.${service}.${section}.${action}`
									}}
									response={response}
									reactions={[]}
									collapsed={collapsed}
									status={status}
									key={`${i}`}
									i={i}
									setExpanded={this.setExpanded.bind(this)}
								/>
							)
						})
					}}
				/>
			</div>
		)
	}
}