import React, { Component } from 'react'
import { observer } from 'mobx-react'
import classnames from 'classnames'
import '../MonitorOn.scss'
import moment from 'moment/moment'
import './Timeline.scss'
import mapData from '../mapData'

const UNITS = ['ms', 'seconds', 'minutes', 'hours', 'day', 'week']

const DATE_FORMAT = 'hh:mm:ss.SSS'

class TimeEvent extends Component {
	state = {
		hover: false
	}

	render () {
		const {request, response, style, duration} = this.props
		const {hover} = this.state

		return (
			<div className={classnames('event', {hover: hover})} style={style}
			     onMouseEnter={() => {
				     this.setState({
					     hover: true
				     })
			     }}
			     onMouseLeave={() => {
				     this.setState({
					     hover: false
				     })
			     }}
			>
				{hover && [
					<div className="start" key="start">Start: {moment(request.time).format(DATE_FORMAT)}</div>,
					<div className="end" key="end">End: {moment(response.time).format(DATE_FORMAT)}</div>,
					<div className="duration" key="duration"><strong>{duration}ms</strong></div>
				]}
			</div>
		)
	}
}

@observer
export default class Timeline extends Component {
	state = {
		unit: 'seconds',
		units: 30,
		zoom: 1
	}

	componentWillReceiveProps () {
		// this.updateStats()
	}

	updateStats () {
		const {store} = this.props
		const data = mapData(store.events || {})



		this.setState({
			startTime,
			endTime,
			maxDuration
		})
	}

	makeGrid () {
		const {unit, units} = this.state

		let result = []

		for (let i = 0; i < units; i++) {
			result.push(
				<div className="col" key={`${unit}_${i}`}>
					{units <= 30 && <span className="number">{units < 1 ? units : i + 1}{unit.slice(0, 3)}</span>}
				</div>
			)
		}

		return result
	}

	mapData () {
		const {store} = this.props
		const data = mapData(store.events || {})
		const {unit, units} = this.state

		let result = []

		data.map((item, i) => {
			const {
				request,
				response
			} = item

			let startTime = data[0] && data[0].request ? data[0].request.time : 0
			let endTime = data[0] && data[0].response ?  data[0].response.time : 0

			const run = ((data) => {
				data.forEach(item => {
					const {
						request,
						response
					} = item

					if (request && request.time) startTime = Math.min(startTime, request.time)
					if (response && response.time) endTime = Math.max(endTime, response.time)
				})
			})(data)

			const duration = response.time - request.time

			const gap = Math.abs(startTime - request.time)
			const timeForUnit = (() => {
				switch (unit) {
					case 'ms':
						return 100
					case 'seconds':
						return 100 / (1000) // 1 second
					case 'minutes':
						return 100 / (60 * 1000) // 1 minute
					case 'hours':
						return 100 / (60 * 60 * 1000) // 1 hour
					case 'day':
						return 100 / (60 * 60 * 1000 * 24) // 1 day
					case 'week':
						return 100 / (60 * 60 * 1000 * 24 * 7) // 1 week
				}
			})()

			const style = {
				width: `${duration * timeForUnit / units}%`,
				left: `${gap * timeForUnit / units}%`
			}

			result.push(
				<TimeEvent
					{...item}
					style={style}
					duration={duration}
					key={`${request.id}_${i}` || String(Math.random())}
				/>
			)
		})

		return result
	}

	changeUnit (e) {
		const {name, value} = e.target

		this.setState({
			unit: value
		})
	}

	changeUnits (e) {
		const {name, value} = e.target

		this.setState({
			units: value
		})
	}

	render () {
		const {store} = this.props
		const data = mapData(store.events || {})

		let maxDuration = 0
		let startTime = data[0] && data[0].request ? data[0].request.time : 0
		let endTime = data[0] && data[0].response ?  data[0].response.time : 0

		const run = ((data) => {
			data.forEach(item => {
				const {
					request,
					response
				} = item

				if (request && request.time) startTime = Math.min(startTime, request.time)
				if (response && response.time) endTime = Math.max(endTime, response.time)

				const duration = response.time - request.time
				maxDuration = duration > maxDuration ? duration : maxDuration
			})
		})(data)

		return (
			<section id="Timeline">
				<div className="info">
					<div>
						Requests: {data.length}
					</div>
					<div>
						Start Time: <span>{startTime ? moment(startTime).format(DATE_FORMAT) : 0}</span>
					</div>
					<div>
						End Time: <span>{endTime ? moment(endTime).format(DATE_FORMAT) : 0}</span>
					</div>
					<div>
						Duration: <span>{startTime && endTime ? moment(endTime - startTime).format(DATE_FORMAT.replace('hh:', '')) : 0}</span>
					</div>
					<div>
						Units:
						<select
							onChange={this.changeUnits.bind(this)}
							value={this.state.units}
						>
							<option value={0.1}>0.1</option>
							<option value={0.5}>0.5</option>
							{[...new Array(200)].map((_, i) => {
								return (
									<option key={i} value={i + 1}>{i + 1}</option>
								)
							})}
						</select>
						<select
							onChange={this.changeUnit.bind(this)}
							value={this.state.unit}
						>
							{UNITS.map((unit, i) => {
								return (
									<option key={i} value={unit}>{unit}</option>
								)
							})}
						</select>
					</div>
					<div>
						Max Duration: {maxDuration}ms
					</div>
				</div>
				<div className="grid">
					{this.makeGrid()}

					<div className="data">
						{this.mapData.call(this)}
					</div>
				</div>
			</section>
		)
	}
}