const path = require('path')
const webpack = require('webpack')
const merge = require('webpack-merge')
const common = require('./common')
const ExtractTextPlugin = require('extract-text-webpack-plugin')
const UglifyJSPlugin = require('uglifyjs-webpack-plugin')
const HtmlWebpackPlugin = require('html-webpack-plugin')
const CleanWebpackPlugin = require('clean-webpack-plugin')

module.exports = merge(common, {
  mode: 'production',
  entry: {
    vendor: ['react', 'react-dom', 'react-router', 'react-router-dom', 'react-redux', 'redux', 'redux-thunk', 'react-loadable'],
    app: ['./src/index.js']
  },
  output: {
    path: path.resolve(__dirname, '../build'),
    filename: '[name].[hash].js',
    chunkFilename: '[name].[hash].js'
  },
  optimization: {
    splitChunks: {
      cacheGroups: {
        vendor: {
          chunks: 'initial',
          name: 'vendor',
          test: 'vendor',
          enforce: true
        },
      }
    },
    runtimeChunk: true
  },
  plugins: [
    new CleanWebpackPlugin('../build'),
    new UglifyJSPlugin({
      uglifyOptions: {
        warnings: false,
        compress: true,
        mangle: true,
        output: {
          comments: false,
          beautify: false
        },
        toplevel: false,
        nameCache: null,
        ie8: false,
        keep_classnames: undefined,
        keep_fnames: false,
        safari10: false,
      }
    }),
    new ExtractTextPlugin('main.css'),
    new HtmlWebpackPlugin({
      template: path.resolve('src/index.html')
    }),
    new webpack.DefinePlugin({
      'process.env': {
        'NODE_ENV': JSON.stringify('production')
      }
    })
  ],
  module: {
    rules: [
      {
        test: /\.js|jsx$/,
        exclude: /node_modules/,
        use: {
          loader: 'babel-loader'
        }
      },
      {
        test: /\.scss$/,
        exclude: /node_modules/,
        use: ExtractTextPlugin.extract({
          fallback: 'style-loader',
          use: ['css-loader', 'sass-loader']
        })
      }
    ]
  }
})