const expect = require('chai').expect
const io = require('socket.io-client')
const request = require('../../../utils/request')

let user = {
	email: 'user1@mycellium.io',
	password: '123456'
}

describe('&create', async () => {
	const mycelliumURL = 'http://localhost:1123'
	const mycelliumClient = io.connect(mycelliumURL)

	it('should deny &create', async () => {
		const res = await request(mycelliumClient, {
			str: 'SET.Offer.Model.&create'
		})

		expect(res.body).to.equal('No token provided')
	})

	it('should login into account', async () => {
		const res = await request(mycelliumClient, {
			str: 'SET.Account.Service.login',
			body: user
		})

		user.token = res.body.token
	})

	it('should deny &create', async () => {
		const res = await request(mycelliumClient, {
			str: 'SET.Offer.Model.&create',
			body: {
				title: 'test offer'
			}
		})

		expect(res.body).to.be.equal('No token provided')
	})

	it('should succeed &create', async () => {
		const title = 'test offer'
		const res = await request(mycelliumClient, {
			str: 'SET.Offer.Model.&create',
			token: user.token,
			body: {
				title
			}
		})

		expect(res.body.title).to.be.equal(title)
	})
})