const md5 = require('md5')
const chai = require('chai')
const chaiHttp = require('chai-http')
const expect = chai.expect
const io = require('socket.io-client')
const request = require('../../../utils/request')

chai.use(chaiHttp)

const binaryParser = function (res, cb) {
	res.setEncoding('binary')
	res.data = ''
	res.on('data', function (chunk) {
		res.data += chunk
	})
	res.on('end', function () {
		cb(null, new Buffer(res.data, 'binary'))
	})
}

describe('Backup', async () => {
	const mycelliumURL = 'http://localhost:1123'
	const mycelliumClient = io.connect(mycelliumURL)

	let admin = {
		email: 'admin@mycellium.io',
		password: '123456'
	}

	it('should register admin', async () => {
		const res = await request(mycelliumClient, {
			str: 'SET.Account.Service.register',
			body: admin
		})
	})

	it('should login admin', async () => {
		const res = await request(mycelliumClient, {
			str: 'SET.Account.Service.login',
			body: admin
		})

		admin.token = res.body.token
	})

	it('should backup', async () => {
		const res = await request(mycelliumClient, {
			str: 'SET.Mycellium.Service._backup',
			token: admin.token
		})
	})

	it('should timeout', done => {
		setTimeout(() => {
			done()
		}, 1000)
	})

	it('should download backup', done => {
		chai
			.request('http://localhost:1235')
			.get('/backup/6')
			.buffer()
			.parse(binaryParser)
			.end(function (err, res) {
				if (err) done(err)
				else {
					expect(res.status).to.be.equal(200)
					expect(res.body)
					done()
				}
			})
	})

	/*it('should create Offer', async () => {
		const res = await request(mycelliumClient, {
			str: 'SET.Offer.Model.&create',
			body: {
				title: 'test offer'
			},
			token: user.token
		})

		offerRes = res

		expect(res.body._id && res.body.title)
	})

	it('should create Match', async () => {
		mycelliumClient.on(`${offerRes.id}@effects`, function (message) {
			expect(message.body._id)
		})
	})

	it('should timeout', done => {
		setTimeout(() => {
			done()
		}, 500)
	})*/
})