const expect = require('chai').expect
const groupBy = require('lodash/groupBy')
const io = require('socket.io-client')
const request = require('../../../utils/request')

const mycelliumURL1 = 'http://localhost:1123'
const mycelliumURL2 = 'http://localhost:1124'
const monitorURL = 'http://localhost:2235'

let admin = {
	email: 'admin@mycellium.io',
	password: '123456'
}
let monitorClient
let responses = []
let promises = []

describe('Cluster', async () => {
	describe('Admin', () => {
		const adminClient = io.connect(mycelliumURL1)
		const userClient1 = io.connect(mycelliumURL1)
		const userClient2 = io.connect(mycelliumURL2)

		it('should register admin', async () => {
			const res = await request(adminClient, {
				str: 'SET.Account.Service.register',
				body: admin
			})

			expect(res.body._id)
			expect(res.body.email).to.equal(admin.email)
		})

		it('should login into account', async () => {
			const res = await request(adminClient, {
				str: 'SET.Account.Service.login',
				body: admin
			})

			admin.token = res.body.token
		})

		it('should register to monitor', async () => {
			monitorClient = io.connect(monitorURL, {query: `token=${admin.token}`})

			monitorClient.on('account', account => {
				console.log(account)
				admin = {
					...account,
					...admin
				}
			})
		})

		it('should get requests events', async () => {
			monitorClient.on('message', message => {
				console.log(message);
				/*responses = [
					...responses,
					...message
				]*/
			})
			console.log(admin);

			const res = await request(monitorClient, {
				str: 'GET.Monitor.Model._get',
				token: admin.token,
				body: {
					skip: 0,
					limit: 30
				}
			})

			console.log(res);

			// await Promise.all(promises)
		})

		/*it('should succeed', (done) => {
			setTimeout(() => {
				done()
			}, 3000)
		}).timeout(10000)*/

		it('should succeed', (done) => {
			setTimeout(() => {
				done()
			}, 500)
		})
	})
})