const onMycelliumEvent = require('./onMycelliumEvent')

const onMycelliumMessage = async function (channel, message) {
	const _message = JSON.parse(message)
	const {id, str, ip, account, socketId} = _message

	const instance = process.env.NODE_APP_INSTANCE
	const name = `${this.name}${typeof instance !== 'undefined' ? `_${instance}` : ''}`

	console.log(`[<<] ${name} | ${str}`.blue)

	if (this.onMycelliumMessage) await this.onMycelliumMessage(channel, _message)

	const split = str.split('.')
	const cell = split[1]
	const section = split[2]
	const action = split[3]

	try {
		if (this.cellReactions) {
			const localReaction = this.cellReactions[cell]
				? this.cellReactions[cell][section]
					? this.cellReactions[cell][section]
						? this.cellReactions[cell][section][action]
						: undefined
					: undefined
				: undefined

			if (localReaction) {
				await localReaction.call(this, _message)
			}
		}

		let response = await onMycelliumEvent.call(this, _message)
		let time = Date.now()

		if (response) {
			this.publish({
				id,
				ip,
				time,
				socketId: socketId || name,
				str: `${str}.SUCCESS`,
				body: response,
				account,
				instance
			})
			console.log(`[>>] ${name} | ${str}.SUCCESS`.green)
		}
	} catch (error) {
		console.error(error)
		this.publish({
			id,
			ip,
			time: Date.now(),
			socketId,
			str: `${str}.ERROR`,
			body: error.message || error,
			account,
			instance
		})
	}
}

module.exports = onMycelliumMessage