const path = require('path')
const fs = require('fs')

const forDirectory = function (directory) {
	let dirs = fs.readdirSync(directory)
	dirs = dirs
		.filter(dir => dir.indexOf('.') < 0)
		.filter(dir => dir.charAt(0) !== '@')
		.filter(dir => dir !== 'node_modules')
		.filter(dir => dir.charAt(0) === dir.charAt(0).toUpperCase())

	let result = {}

	if (dirs.length > 0)
		dirs
			.forEach(dir => {
				const actions = fs.readdirSync(`${directory}/${dir}`)

				result[dir] = {}

				if (actions.length > 0)
					actions
						.forEach(action => {
							const _action = action.replace('.js', '')

							const instance = process.env.NODE_APP_INSTANCE
							const name = `${this.name}${typeof instance !== 'undefined' ? `_${instance}` : ''}`

							console.log(`√ ${name} | [SET.${this.name}.${dir}.${_action}]`)

							result[dir] = {
								...result[dir],
								[_action]: require(path.resolve(directory, dir, action))
							}
						})
			})

	return result
}

const setActions = function () {
	if (this.config.cellPath) {
		this.cellActions = {}

		try {
			this.cellActions = forDirectory.call(this, this.config.cellPath)
		} catch (error) {
			console.error(`Error @ ${this.config.cellPath}`.red)
			console.error(error)
		}
	}

	if (this.config.modulePath) {
		this.moduleActions = {}

		try {
			this.moduleActions = forDirectory.call(this, this.config.modulePath)
		} catch (error) {
			console.error(`Error @ ${this.config.modulePath}`.red)
			console.error(error)
		}
	}

	if (this.config.selfPath) {
		this.selfActions = {}

		try {
			this.selfActions = forDirectory.call(this, this.config.selfPath)
		} catch (error) {
			console.error(`Error @ ${this.config.selfPath}`.red)
			console.error(error)
		}
	}
}

module.exports = setActions