require('colors')
const path = require('path')
const fs = require('fs')

const forDirectory = function (directory) {
	const _path = path.resolve(directory, '@')
	const exists = fs.existsSync(_path)
	const instance = process.env.NODE_APP_INSTANCE
	const name = `${this.name}${typeof instance !== 'undefined' ? `_${instance}` : ''}`

	let result = {}

	if (exists) {
		let dirs = fs.readdirSync(_path)

		dirs = dirs.filter(dir => dir.indexOf('.') < 0)

		if (dirs.length > 0) {
			dirs
				.forEach(dir => {
					result[dir] = {}

					const _path = `${directory}/@/${dir}`
					const exists = fs.existsSync(_path)

					if (exists) {
						const actions = fs.readdirSync(_path)

						if (actions.length > 0)
							actions
								.forEach(action => {
									const isFile = action.indexOf('.js') > -1

									if (isFile) {
										const _action = action.replace('.js', '')

										console.log(`√ ${name} | @ [${this.name}.${dir}.${_action}]`)

										result[dir] = {
											...result[dir],
											[_action]: require(path.resolve(directory, '@', dir, action))
										}
									} else {
										let actions = fs.readdirSync(path.resolve(directory, '@', dir, action))

										if (actions.length > 0)
											actions
												.forEach(_action => {
													const __action = _action.replace('.js', '')

													console.log(`√ ${name} | @ [${dir}.${action}.${__action}]`)

													result[dir][action] = {
														...result[dir][action],
														[__action]: require(path.resolve(directory, '@', dir, action, _action))
													}
												})
									}
								})
					}
				})
		}
	}

	return result
}

const setReactions = function () {
	if (this.config.cellPath) {
		this.cellReactions = {}

		try {
			this.cellReactions = forDirectory.call(this, this.config.cellPath)
		} catch (error) {
			console.error(`Error @ ${this.config.cellPath}`.red)
			console.error(error)
		}
	}

	if (this.config.modulePath) {
		this.moduleReactions = {}

		try {
			this.moduleReactions = forDirectory.call(this, this.config.modulePath)
		} catch (error) {
			console.error(`Error @ ${this.config.modulePath}`.red)
			console.error(error)
		}
	}

	if (this.config.selfPath) {
		this.selfReactions = {}

		try {
			this.selfReactions = forDirectory.call(this, this.config.selfPath)
		} catch (error) {
			console.error(`Error @ ${this.config.selfPath}`.red)
			console.error(error)
		}
	}
}

module.exports = setReactions