require('colors')
const jwt = require('jsonwebtoken')
const onSocketMessage = require('./onSocketMessage')
const uuidv4 = require('uuid/v4')
const redis = require('redis')
const client = redis.createClient()

const onSocketConnection = async function (socket) {
	const ip = socket.request.connection.remoteAddress

	const connect = async (token) => {
		try {
			if (token) {
				console.log(`ADMIN CONNECTED TO MONITOR ${socket.id}`.bgMagenta.black)
				await client.set('adminSocket', socket.id)
				const admin = this.config.admin || this.mycellium.admin
				const secret = this.config.secret || this.mycellium.secret

				console.log(admin, secret)

				let account = jwt.verify(token, secret)

				if (account && (account.email === admin)) {
					socket.emit('account', {
						account,
						monitorOn: this.config.monitorOn
					})
				}
			}
		} catch (error) {
			socket.emit('account', 'Unauthorized')
		}
	}

	const handShakeLogic = async (socket) => {
		const {token} = socket.handshake.query

		if (token) {
			await connect(token)
		}
	}

	if (this.name === 'Monitor') {
		await handShakeLogic(socket)

		/*const disconnect = () => {
			this.io.sockets.connected[socket.id].disconnect()
		}

		socket.on('disconnected', disconnect)*/
		socket.on('account', async message => {
			if (message.token) {
				await connect(message.token)
			}
		})
		// socket.on('account-disconnect', disconnect)
	}

	socket.on('request', async message => {
		const _message = {
			...message,
			socketId: socket.id,
			time: Date.now(),
			id: message.id || uuidv4(),
			ip,
			instance: process.env.NODE_APP_INSTANCE || -1
		}

		await onSocketMessage.call(this, _message)
	})

	// FIXME: rate limit
	/*if (this.config.rateLimit) {
		this.floods[socket.id] = {}
	}*/
}

module.exports = onSocketConnection