const redis = require('redis')

const onCellMessage = require('./cell/onCellMessage')

const subscribeToCells = async function () {
	try {
		const {
			config,
			mycellium,
			subscribers
		} = this

		let cells

		if (config.subscribeTo) {
			cells = config.subscribeTo
		} else {
			cells = {...config.cells ? config.cells : mycellium ? mycellium.cells : {}}
			delete cells[this.name]
		}

		Object.keys(cells).forEach(cell => {
			let host = 'localhost'

			if (cells[cell].mycologies && cells[cell].mycologies[this.env] && cells[cell].mycologies[this.env].host) {
				host = cells[cell].mycologies[this.env].host
			}

			const instance = process.env.NODE_APP_INSTANCE
			const name = `${this.name}${typeof instance !== 'undefined' ? `_${instance}` : ''}`
			const channel = `${cell}${typeof instance !== 'undefined' ? `_${instance}` : ''}`

			subscribers[channel] = redis.createClient(6379, host)
			subscribers[channel].subscribe(channel)

			subscribers[channel].on('message', onCellMessage.bind(this))
			console.log(`√ ${name} | Subscribed to ${channel} [${host}]`)
		})
	} catch (error) {
		throw new Error(error)
	}
}

module.exports = subscribeToCells